==> flink-1.13.6-src.tgz: flink-1.13.6/flink-table/flink-table-common/src/test/java/org/apache/flink/table/types/inference/utils/FunctionDefinitionMock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.types.inference.utils;

import org.apache.flink.table.catalog.DataTypeFactory;
import org.apache.flink.table.functions.FunctionDefinition;
import org.apache.flink.table.functions.FunctionKind;
import org.apache.flink.table.types.inference.TypeInference;

/** {@link FunctionDefinition} mock for testing purposes. */
public class FunctionDefinitionMock implements FunctionDefinition {

    public FunctionKind functionKind;

    public TypeInference typeInference;

    @Override
    public FunctionKind getKind() {
        return functionKind;
    }

    @Override
    public TypeInference getTypeInference(DataTypeFactory typeFactory) {
        return typeInference;
    }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-table/flink-table-common/src/test/java/org/apache/flink/table/types/inference/utils/FunctionDefinitionMock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.types.inference.utils;

import org.apache.flink.table.catalog.DataTypeFactory;
import org.apache.flink.table.functions.FunctionDefinition;
import org.apache.flink.table.functions.FunctionKind;
import org.apache.flink.table.types.inference.TypeInference;

/** {@link FunctionDefinition} mock for testing purposes. */
public class FunctionDefinitionMock implements FunctionDefinition {

    public FunctionKind functionKind;

    public TypeInference typeInference;

    public FunctionDefinitionMock(FunctionKind functionKind, TypeInference typeInference) {
        this.functionKind = functionKind;
        this.typeInference = typeInference;
    }

    public FunctionDefinitionMock() {
        this(null, null);
    }

    @Override
    public FunctionKind getKind() {
        return functionKind;
    }

    @Override
    public TypeInference getTypeInference(DataTypeFactory typeFactory) {
        return typeInference;
    }
}
